@@ -1,14 +1,14 @@
 from protmo.pm import *
 from protmo.ast import *
-from protmo.ast_to_grpc_ast import AstToGrpcAst
+from protmo.grpc_ast import AstToGrpcAst
 
 
 def create_proto_file(package: str) -> None:
 
     content = 'syntax = "proto3";\n\n'
     content += f'package {package};\n\n'
-    for modelClass in (Message.__subclasses__()):
-        msg = MessageInfo(modelClass)
+    for model_class in (Message.__subclasses__()):
+        msg = MessageInfo(model_class)
         proto_messages = AstToGrpcAst(msg)
         content += f'\n// {msg.name} ------\n\n'
         content += str(proto_messages.messages[0]) + '\n\n'
